@@ -474,22 +474,29 @@ sub method
 
   my $address = $dkim->message_originator;
 
-Returns the "originator address" found in the message. This is typically
-the (first) name and email address found in the From: header. The returned
-object is of type L<Mail::Address>. To get just the email address part, do:
+Returns the "originator address" found in the message, as a
+L<Mail::Address> object.
+This is typically the (first) name and email address found in the
+From: header. If there is no From: header,
+then an empty L<Mail::Address> object is returned.
+
+To get just the email address part, do:
 
   my $email = $dkim->message_originator->address;
 
+See also L</"message_sender()">.
 
 =head2 message_sender() - access the "From" or "Sender" header
 
   my $address = $dkim->message_sender;
 
-Returns the "sender" found in the message. This is typically the (first)
-name and email address found in the Sender: header. If there is no Sender:
-header, it is the first name and email address in the From: header.
-The returned object is of type Mail::Address, so to get just the email
-address part, do:
+Returns the "sender" found in the message, as a L<Mail::Address> object.
+This is typically the (first) name and email address found in the
+Sender: header. If there is no Sender: header, it is the first name and
+email address in the From: header. If neither header is present,
+then an empty L<Mail::Address> object is returned.
+
+To get just the email address part, do:
 
   my $email = $dkim->message_sender->address;
 
